#' Returns summary counts of occurrence records by one-degree cell for a single
#' 		taxon, country, dataset, data publisher or data network.
#'
#' @export
occurrencedensity <- function()
{
	message("Function deprecated. Now use densitylist()")
}
